@@ -81,5 +81,8 @@ module.exports = {
       }
     }
   },
+  corePlugins: {
+    preflight: false
+  },
   plugins: [require('@tailwindcss/typography')]
 };
